Supplementary Specification
===========================

Usability
---------

The user interface must be functional on both desktop computers
as well as on smartphones.

Reliability
-----------

The system must be available 99.99% of the time (that is,
there must be no more than a few seconds of outage a day).

Performance
-----------

The system should be able to support up to 1000 users
simultaneously performing different tasks at any given time.

Supportability
--------------

TBD

Security
--------

TBD
